@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """
 Functions to extract various elements of interest from documents already parsed
-by `spaCy <http://spacy.io/>`_, such as n-grams, named entities, subject-verb-object
-triples, and acronyms.
+by spaCy, such as n-grams, named entities, subject-verb-object triples, and
+acronyms.
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
 
@@ -18,8 +18,8 @@ from spacy.tokens.span import Span as SpacySpan
 
 from . import compat
 from . import constants
-from . import spacy_utils
 from . import text_utils
+from .spacier import utils as spacy_utils
 
 
 def words(doc,
@@ -39,20 +39,20 @@ def words(doc,
             IS NOT included in this param
         exclude_pos (str or Set[str]): remove words whose part-of-speech tag
             IS in the specified tags
-        min_freq (int): remove words that occur in `doc` fewer than
-            `min_freq` times
+        min_freq (int): remove words that occur in ``doc`` fewer than
+            ``min_freq`` times
 
     Yields:
         ``spacy.Token``: the next token from ``doc`` passing specified filters
         in order of appearance in the document
 
     Raises:
-        TypeError: if `include_pos` or `exclude_pos` is not a str, a set of str,
+        TypeError: if ``include_pos`` or ``exclude_pos`` is not a str, a set of str,
             or a falsy value
 
     Note:
-        Filtering by part-of-speech tag uses the universal POS tag set,
-        http://universaldependencies.org/u/pos/.
+        Filtering by part-of-speech tag uses the universal POS tag set; for details,
+        check spaCy's docs: https://spacy.io/api/annotation#pos-tagging
     """
     words_ = (w for w in doc if not w.is_space)
     if filter_stops is True:
@@ -121,12 +121,12 @@ def ngrams(doc, n,
 
     Raises:
         ValueError: if ``n`` < 1
-        TypeError: if `include_pos` or `exclude_pos` is not a str, a set of str,
+        TypeError: if ``include_pos`` or ``exclude_pos`` is not a str, a set of str,
             or a falsy value
 
     Note:
-        Filtering by part-of-speech tag uses the universal POS tag set,
-        http://universaldependencies.org/u/pos/.
+        Filtering by part-of-speech tag uses the universal POS tag set; for details,
+        check spaCy's docs: https://spacy.io/api/annotation#pos-tagging
     """
     if n < 1:
         raise ValueError('n must be greater than or equal to 1')
@@ -204,47 +204,33 @@ def named_entities(doc,
                big deal, but watch out if you're counting on determiner-less
                entities associated with the doc downstream.
 
-        min_freq (int): remove named entities that occur in `doc` fewer
-            than `min_freq` times
+        min_freq (int): remove named entities that occur in ``doc`` fewer
+            than ``min_freq`` times
 
     Yields:
         ``spacy.Span``: the next named entity from ``doc`` passing all specified
         filters in order of appearance in the document
 
     Raises:
-        TypeError: if `include_types` or `exclude_types` is not a str, a set of
+        TypeError: if ``include_types`` or ``exclude_types`` is not a str, a set of
             str, or a falsy value
     """
-    if hasattr(doc, 'spacy_doc'):
+    if hasattr(doc, "spacy_doc"):
         nes = doc.spacy_doc.ents
     else:
         nes = doc.ents
+    include_types = _parse_ne_types(include_types, "include")
+    exclude_types = _parse_ne_types(exclude_types, "exclude")
     if include_types:
         if isinstance(include_types, compat.unicode_):
-            include_types = include_types.upper()
-            if include_types == 'NUMERIC':
-                include_types = constants.NUMERIC_NE_TYPES  # we now go to next if block
-            else:
-                nes = (ne for ne in nes if ne.label_ == include_types)
-        if isinstance(include_types, (set, frozenset, list, tuple)):
-            include_types = {type_.upper() for type_ in include_types}
+            nes = (ne for ne in nes if ne.label_ == include_types)
+        elif isinstance(include_types, (set, frozenset, list, tuple)):
             nes = (ne for ne in nes if ne.label_ in include_types)
-        else:
-            msg = 'invalid `include_types` type: "{}"'.format(type(include_types))
-            raise TypeError(msg)
     if exclude_types:
         if isinstance(exclude_types, compat.unicode_):
-            exclude_types = exclude_types.upper()
-            if exclude_types == 'NUMERIC':
-                exclude_types = constants.NUMERIC_NE_TYPES  # we now go to next if block
-            else:
-                nes = (ne for ne in nes if ne.label_ != exclude_types)
-        if isinstance(exclude_types, (set, frozenset, list, tuple)):
-            exclude_types = {type_.upper() for type_ in exclude_types}
+            nes = (ne for ne in nes if ne.label_ != exclude_types)
+        elif isinstance(exclude_types, (set, frozenset, list, tuple)):
             nes = (ne for ne in nes if ne.label_ not in exclude_types)
-        else:
-            msg = 'invalid `exclude_types` type: "{}"'.format(type(exclude_types))
-            raise TypeError(msg)
     if drop_determiners is True:
         nes = (
             ne if ne[0].pos != DET else SpacySpan(ne.doc, ne.start + 1, ne.end, label=ne.label, vector=ne.vector)
@@ -252,13 +238,37 @@ def named_entities(doc,
     if min_freq > 1:
         nes = list(nes)
         freqs = itertoolz.frequencies(ne.lower_ for ne in nes)
-        nes = (ne for ne in nes
-               if freqs[ne.lower_] >= min_freq)
+        nes = (ne for ne in nes if freqs[ne.lower_] >= min_freq)
 
     for ne in nes:
         yield ne
 
 
+def _parse_ne_types(ne_types, which):
+    if not ne_types:
+        return None
+    elif isinstance(ne_types, compat.unicode_):
+        ne_types = ne_types.upper()
+        # replace the shorthand numeric case by its corresponding constant
+        if ne_types == "NUMERIC":
+            return constants.NUMERIC_NE_TYPES
+        else:
+            return ne_types
+    elif isinstance(ne_types, (set, frozenset, list, tuple)):
+        ne_types = {ne_type.upper() for ne_type in ne_types}
+        # again, replace the shorthand numeric case by its corresponding constant
+        # and include it in the set in case other types are specified
+        if any(ne_type == "NUMERIC" for ne_type in ne_types):
+            return ne_types.union(constants.NUMERIC_NE_TYPES)
+        else:
+            return ne_types
+    else:
+        allowed_types = (None, compat.unicode_, set, frozenset, list, tuple)
+        raise TypeError(
+            "{}_types = {} is {}, which is not one of the allowed types: {}".format(
+                which, ne_types, type(ne_types), allowed_types))
+
+
 def noun_chunks(doc, drop_determiners=True, min_freq=1):
     """
     Extract an ordered sequence of noun chunks from a spacy-parsed doc, optionally
@@ -268,8 +278,8 @@ def noun_chunks(doc, drop_determiners=True, min_freq=1):
         doc (``textacy.Doc`` or ``spacy.Doc``)
         drop_determiners (bool): remove leading determiners (e.g. "the")
             from phrases (e.g. "the quick brown fox" => "quick brown fox")
-        min_freq (int): remove chunks that occur in `doc` fewer than
-            `min_freq` times
+        min_freq (int): remove chunks that occur in ``doc`` fewer than
+            ``min_freq`` times
 
     Yields:
         ``spacy.Span``: the next noun chunk from ``doc`` in order of appearance
@@ -630,7 +640,7 @@ def semistructured_statements(doc, entity, cue='be', ignore_entity_case=True,
         doc (``textacy.Doc`` or ``spacy.Doc``)
         entity (str): a noun or noun phrase of some sort (e.g. "President Obama",
             "global warming", "Python")
-        cue (str): verb lemma with which `entity` is associated
+        cue (str): verb lemma with which ``entity`` is associated
             (e.g. "talk about", "have", "write")
         ignore_entity_case (bool): if True, entity matching is case-independent
         min_n_words (int): min number of tokens allowed in a matching fragment
