@@ -39,7 +39,7 @@ def sgrank(doc, ngrams=(1, 2, 3, 4, 5, 6), normalize='lemma', window_width=1500,
         normalize (str or callable): If 'lemma', lemmatize terms; if 'lower',
             lowercase terms; if None, use the form of terms as they appeared in
             ``doc``; if a callable, must accept a ``spacy.Span`` and return a str,
-            e.g. :func:`textacy.spacy_utils.normalized_str()`
+            e.g. :func:`textacy.spacier.utils.get_normalized_text()`
         window_width (int): Width of sliding window in which term
             co-occurrences are determined to occur. Note: Larger values may
             dramatically increase runtime, owing to the larger number of
@@ -183,7 +183,7 @@ def textrank(doc, normalize='lemma', n_keyterms=10):
         normalize (str or callable): if 'lemma', lemmatize terms; if 'lower',
             lowercase terms; if None, use the form of terms as they appeared in
             ``doc``; if a callable, must accept a ``spacy.Token`` and return a str,
-            e.g. :func:`textacy.spacy_utils.normalized_str()`
+            e.g. :func:`textacy.spacier.utils.get_normalized_text()`
         n_keyterms (int or float): if int, number of top-ranked terms
             to return as keyterms; if float, must be in the open interval (0, 1),
             representing the fraction of top-ranked terms to return as keyterms
@@ -210,7 +210,7 @@ def singlerank(doc, normalize='lemma', n_keyterms=10):
         normalize (str or callable): if 'lemma', lemmatize terms; if 'lower',
             lowercase terms; if None, use the form of terms as they appeared in
             ``doc``; if a callable, must accept a ``spacy.Token`` and return a str,
-            e.g. :func:`textacy.spacy_utils.normalized_str()`
+            e.g. :func:`textacy.spacier.utils.get_normalized_text()`
         n_keyterms (int or float): if int, number of top-ranked terms
             to return as keyterms; if float, must be in the open interval (0, 1),
             representing the fraction of top-ranked terms to return as keyterms
@@ -242,7 +242,7 @@ def key_terms_from_semantic_network(doc, normalize='lemma',
         normalize (str or callable): if 'lemma', lemmatize terms; if 'lower',
             lowercase terms; if None, use the form of terms as they appeared in
             ``doc``; if a callable, must accept a ``spacy.Token`` and return a str,
-            e.g. :func:`textacy.spacy_utils.normalized_str()`
+            e.g. :func:`textacy.spacier.utils.get_normalized_text()`
         window_width (int): width of sliding window in which term
             co-occurrences are said to occur
         edge_weighting ('binary', 'cooc_freq'}): method used to
@@ -567,13 +567,15 @@ def rank_nodes_by_bestcoverage(graph, k, c=1, alpha=1.0):
     """
     alpha = float(alpha)
 
-    nodes_list = list(dict(graph.nodes()))
+    nodes_list = [node for node in graph]
+    if len(nodes_list) == 0:
+        LOGGER.warning('``graph`` is empty!')
+        return {}
 
     # ranks: array of PageRank values, summing up to 1
     ranks = nx.pagerank_scipy(graph, alpha=0.85, max_iter=100, tol=1e-08, weight='weight')
     sorted_ranks = sorted(ranks.items(), key=operator.itemgetter(1), reverse=True)
-
-    avg_degree = sum(deg for _, deg in graph.degree()) / len(nodes_list)
+    avg_degree = sum(dict(graph.degree()).values()) / len(nodes_list)
     # relaxation parameter, k' in the paper
     k_prime = int(k * avg_degree * c)
 
@@ -672,9 +674,13 @@ def rank_nodes_by_divrank(graph, r=None, lambda_=0.5, alpha=0.5):
         LOGGER.warning('``graph`` is empty!')
         return {}
 
+    # specify the order of nodes to use in creating the matrix
+    # and then later recovering the values from the order index
+    nodes_list = [node for node in graph]
+
     # create adjacency matrix, i.e.
     # n x n matrix where entry W_ij is the weight of the edge from V_i to V_j
-    W = nx.to_numpy_matrix(graph, weight='weight').A
+    W = nx.to_numpy_matrix(graph, nodelist=nodes_list, weight='weight').A
     n = W.shape[1]
 
     # create flat prior personalization vector if none given
@@ -714,7 +720,6 @@ def rank_nodes_by_divrank(graph, r=None, lambda_=0.5, alpha=0.5):
                      key=operator.itemgetter(1), reverse=True)
 
     # replace node number by node value
-    nodes_list = list(dict(graph.nodes()))
     divranks = {nodes_list[result[0]]: result[1] for result in results}
 
     return divranks
